@@ -1,5 +1,7 @@
 #include <linux/pci.h>
+#include <linux/mm.h>
 #include <asm/io.h>
+#include "kernel26compat.h"
 #include "svgalib_helper.h"
 
 int vga_test_vsync(struct sh_pci_device *dev) {
@@ -9,11 +11,17 @@ int vga_test_vsync(struct sh_pci_device *dev) {
 void vga_ack_vsync(struct sh_pci_device *dev) {
     int pb;
     
-/* disable interrupt, clear pending */
+/* clear pending */
     outb(0x11, 0x3d4);
     pb = inb(0x3d5);
     outb(0x11, 0x3d4);
     outb((pb&0xef) | 0x20, 0x3d5);
+
+/* disable interrupts */
+    outb(0x11, 0x3d4);
+    pb = inb(0x3d5);
+    outb(0x11, 0x3d4);
+    outb(pb | 0x20 , 0x3d5);
 }
 
 void vga_enable_vsync(struct sh_pci_device *dev) {
@@ -39,11 +47,17 @@ int io_test_vsync(struct sh_pci_device *dev) {
 void io_ack_vsync(struct sh_pci_device *dev) {
     int pb;
     
-/* disable interrupt, clear pending */
+/* clear pending */
     outb(0x11, dev->iobase+0x3d4);
     pb = inb(dev->iobase+0x3d5);
     outb(0x11, dev->iobase+0x3d4);
     outb((pb&0xef) | 0x20, dev->iobase+0x3d5);
+
+/* disable interrupts */
+    outb(0x11, dev->iobase+0x3d4);
+    pb = inb(dev->iobase+0x3d5);
+    outb(0x11, dev->iobase+0x3d4);
+    outb(pb | 0x20 , dev->iobase+0x3d5);
 }
 
 void io_enable_vsync(struct sh_pci_device *dev) {
@@ -69,11 +83,17 @@ int mm_test_vsync(struct sh_pci_device *dev) {
 void mm_ack_vsync(struct sh_pci_device *dev) {
     int pb;
     
-/* disable interrupt, clear pending */
+/* clear pending */
     writeb(0x11, dev->iobase+0x3d4);
     pb = readb(dev->iobase+0x3d5);
     writeb(0x11, dev->iobase+0x3d4);
     writeb((pb&0xef) | 0x20, dev->iobase+0x3d5);
+
+/* disable interrupts */
+    writeb(0x11, dev->iobase+0x3d4);
+    pb = readb(dev->iobase+0x3d5);
+    writeb(0x11, dev->iobase+0x3d4);
+    writeb(pb | 0x20 , dev->iobase+0x3d5);
 }
 
 void mm_enable_vsync(struct sh_pci_device *dev) {
@@ -104,7 +124,7 @@ void s3_ack_vsync(struct sh_pci_device *dev) {
 	writel(0x001, dev->iobase+0x8504);
 }
 
-static uint32_t saved_pmc;
+static uint32_t saved_pmc=0xffffffff;
 
 int nv3_test_vsync(struct sh_pci_device *dev) {
      return readl(dev->iobase+0x400100)&0x100;
@@ -117,7 +137,8 @@ void nv3_ack_vsync(struct sh_pci_device *dev) {
     writel(0x100, 	dev->iobase + 0x400100);
     writel(0, 		dev->iobase + 0x000140);
     writel(0, 		dev->iobase + 0x400140);
-    writel(saved_pmc,	dev->iobase + 0x000200); 
+	if(saved_pmc!=0xffffffff)
+		writel(saved_pmc,	dev->iobase + 0x000200); 
 
 }
 
@@ -172,11 +193,11 @@ int rage_test_vsync(struct sh_pci_device *dev) {
 }
 
 void rage_ack_vsync(struct sh_pci_device *dev) {
-    outl((inl(dev->iobase + 0x18) & 0xfffffff8) | 4, dev->iobase + 0x18); 
+    outl((inl(dev->iobase + 0x18) & 0xfffffff8) | 12, dev->iobase + 0x18); 
 }
 
 void rage_enable_vsync(struct sh_pci_device *dev) {
-    outl((inl(dev->iobase + 0x18) & 0xfffffff8) | 6, dev->iobase + 0x18); 
+    outl((inl(dev->iobase + 0x18) & 0xfffffff8) | 14, dev->iobase + 0x18); 
 }
 
 int rendition_test_vsync(struct sh_pci_device *dev) {    
@@ -203,12 +224,14 @@ void vga_init_vsync(struct sh_pci_device *dev) {
             dev->test_vsync = mm_test_vsync;
             dev->ack_vsync = mm_ack_vsync;
             dev->enable_vsync = mm_enable_vsync;            
+            dev->disable_vsync = mm_ack_vsync;
             break;
         case PCI_VENDOR_ID_SI: /* SiS */
             dev->iobase = dev->mem[2]-0x380;
             dev->test_vsync = io_test_vsync;
             dev->ack_vsync = io_ack_vsync;
             dev->enable_vsync = io_enable_vsync;
+            dev->disable_vsync = io_ack_vsync;
             break;
         case PCI_VENDOR_ID_NVIDIA_SGS:
             dev->iobase = (unsigned long)ioremap(dev->mem[0],0x800000);
@@ -216,10 +239,12 @@ void vga_init_vsync(struct sh_pci_device *dev) {
                 dev->test_vsync = nv3_test_vsync;
                 dev->ack_vsync = nv3_ack_vsync;
                 dev->enable_vsync = nv3_enable_vsync;
+                dev->disable_vsync = nv3_ack_vsync;
             } else {
                 dev->test_vsync = nv4_test_vsync;
                 dev->ack_vsync = nv4_ack_vsync;
                 dev->enable_vsync = nv4_enable_vsync;
+                dev->disable_vsync = nv4_ack_vsync;
             }
             break;
         case PCI_VENDOR_ID_NVIDIA:
@@ -227,15 +252,21 @@ void vga_init_vsync(struct sh_pci_device *dev) {
             dev->test_vsync = nv4_test_vsync;
             dev->ack_vsync = nv4_ack_vsync;
             dev->enable_vsync = nv4_enable_vsync;
+			dev->disable_vsync = nv4_ack_vsync;
             break;
         case PCI_VENDOR_ID_ATI:
             id=dev->id;
     
             if( (id==0x4c45) ||
                 (id==0x4c46) ||
+                (id==0x4c57) ||
+                (id==0x4c59) ||
+                (id==0x4c5a) ||
                 (id==0x4d46) ||
                 (id==0x4d4c) ||
+				(id==0x4242) ||
                 ((id>>8)==0x50) ||
+                ((id>>8)==0x51) || 
                 ((id>>8)==0x52) ||
                 ((id>>8)==0x53) ||
                 ((id>>8)==0x54)) {                
@@ -243,21 +274,13 @@ void vga_init_vsync(struct sh_pci_device *dev) {
                     dev->test_vsync = r128_test_vsync;
                     dev->ack_vsync = r128_ack_vsync;
                     dev->enable_vsync = r128_enable_vsync;
-            } else 
-            if( (id==0x4242) ||
-                (id==0x4c57) ||
-                (id==0x4c59) ||
-                (id==0x4c5a) ||
-                ((id>>8)==0x51)) {
-                    dev->iobase = (unsigned long)ioremap(dev->mem[2], 16384);
-                    dev->test_vsync = r128_test_vsync;
-                    dev->ack_vsync = r128_ack_vsync;
-                    dev->enable_vsync = r128_enable_vsync;
+                    dev->disable_vsync = r128_ack_vsync;
             } else {
                     dev->iobase = dev->mem[1];
                     dev->test_vsync = rage_test_vsync;
                     dev->ack_vsync = rage_ack_vsync;
                     dev->enable_vsync = rage_enable_vsync;
+                    dev->disable_vsync = rage_ack_vsync;
             }
             break;
         case PCI_VENDOR_ID_RENDITION:
@@ -265,17 +288,20 @@ void vga_init_vsync(struct sh_pci_device *dev) {
             dev->test_vsync = rendition_test_vsync;
             dev->ack_vsync = rendition_ack_vsync;
             dev->enable_vsync = rendition_enable_vsync;
+            dev->disable_vsync = rendition_ack_vsync;
             break;
 		case PCI_VENDOR_ID_S3:
 			dev->iobase = (unsigned long)ioremap(dev->mem[0]+0x1000000, 0x10000);
             dev->test_vsync = s3_test_vsync;
             dev->ack_vsync = s3_ack_vsync;
             dev->enable_vsync = s3_enable_vsync;
+            dev->disable_vsync = s3_ack_vsync;
 			break;
         default:
             dev->test_vsync = vga_test_vsync;
             dev->ack_vsync = vga_ack_vsync;
             dev->enable_vsync = vga_enable_vsync;
+            dev->disable_vsync = vga_ack_vsync;
             dev->iobase = 0;
     }
     
