@@ -7,19 +7,29 @@
 #  undef KERNEL_2_6
 # endif
 
-# define my_io_remap_page_range(vma, start, ofs, len, prot) io_remap_page_range(start,ofs,len,prot)
-
+# if defined (PG_chainlock)
+#  define my_io_remap_page_range(vma, start, ofs, len, prot) \
+		io_remap_page_range(vma,start,ofs,len,prot)
+# else
+#  define my_io_remap_page_range(vma, start, ofs, len, prot) \
+		io_remap_page_range(start,ofs,len,prot)
+# endif
+# ifndef IRQ_HANDLED 
 typedef void irqreturn_t;
-# define IRQ_NONE
-# define IRQ_HANDLED
+#  define IRQ_NONE
+#  define IRQ_HANDLED
+# endif
 
 #else /* Kernel 2.6 */
 
+#define NO_TASK
+
 # ifndef KERNEL_2_6
 #  define KERNEL_2_6
 # endif
 
-# define my_io_remap_page_range(vma, start, ofs, len, prot) io_remap_page_range(vma,start,ofs,len,prot)
+# define my_io_remap_page_range(vma, start, ofs, len, prot) \
+		io_remap_page_range(vma,start,ofs,len,prot)
 
 # define pci_present() 1
 
@@ -29,7 +39,6 @@ typedef void* devfs_handle_t;
 
 #endif
 
-
 /* These are also not present in 2.6 kernels ... */
 #if (!defined _LINUX_DEVFS_FS_KERNEL_H) || (defined KERNEL_2_6)
 static inline int devfs_register_chrdev (unsigned int major, const char *name,
@@ -43,11 +52,12 @@ static inline int devfs_unregister_chrdev (unsigned int major,const char *name)
 }
 #endif
 
-
-/* Our main.c really do not like MINOR from 2.6 kernels ... */
-#if (defined MINOR) && (!defined KERNEL_2_6)
+#if (defined MINOR)
 # define my_minor(x) MINOR(x)
 #else
 # define my_minor(x) minor(x)
 #endif
-	
+
+#if !defined(MODULE_VERSION) 
+# define MODULE_VERSION(x)
+#endif
