@@ -18,12 +18,11 @@
 #include <linux/interrupt.h>
 #include <linux/pci.h>
 #include <linux/devfs_fs_kernel.h>
+#include <linux/mm.h>
 
 #include <linux/sched.h>
 #include <linux/wait.h>
 
-#include "kernel26compat.h"
-
 #include <asm/uaccess.h>
 #include <asm/system.h>   /* cli(), *_flags */
 #include <asm/segment.h>  /* memcpy and such */
@@ -31,12 +30,15 @@
 #include <asm/pgtable.h>
 #include <asm/irq.h>
 
+#include "kernel26compat.h"
+
 #include "svgalib_helper.h"
 
 #include "../../src/vgaversion.h"
 
 #include "i810.h"
 #include "interrupt.h"
+#include "displaystart.h"
 
 int debug=0;
 static int all_devices=0;
@@ -93,18 +95,37 @@ static irqreturn_t vsync_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 			return IRQ_NONE;
 		}
         vga_ack_vsync(dev);
+    	vsync=0;
+    	wake_up_interruptible(&vsync_wait);
     } else {
         if(!dev->test_vsync(dev)) {
 			return IRQ_NONE;
 		}
         dev->ack_vsync(dev);
+    	dev->vsync=0;
+    	wake_up_interruptible(&dev->vsync_wait);
+
+#ifndef NO_TASK
+		wake_up_interruptible(&dev->startad_wait);
+#endif
     }
 
-    vsync=0;
-    wake_up_interruptible(&vsync_wait);
 	return IRQ_HANDLED;
 }
 
+#ifndef NO_TASK
+static void task_startad(void *data) {
+	struct sh_pci_device *dev = (struct sh_pci_device *)data;
+	int i;
+	
+	i=dev->dev->irq;
+	dev->enable_vsync(dev);
+	interruptible_sleep_on(&dev->vsync_wait);
+	dev->ack_vsync(dev);
+	set_displaystart(dev);
+	dev->startad=-1;
+}
+#endif
 
 static int svgalib_helper_ioctl( struct inode *inode, struct file *filp, 
                           unsigned int cmd, unsigned long arg) {
@@ -118,7 +139,6 @@ static int svgalib_helper_ioctl( struct inode *inode, struct file *filp,
     u8 pb;
     u16 pw;
     u32 pl;
-    void *dev_id;
     unsigned char *outb_str;
 
     if(_IOC_TYPE(cmd)!=SVGAHELPER_MAGIC) {
@@ -288,48 +308,45 @@ static int svgalib_helper_ioctl( struct inode *inode, struct file *filp,
                 else return -EINVAL;
             break;
 #endif
-
         case _IOC_NR(SVGAHELPER_WAITRETRACE):
 
             /* Workaround for nvidia cards, which are not vga compatible */
 //            if(!minor && num_devices==2) minor=1;
 
             if(minor) {
+				int i;
                 i=sh_pci_devs[minor]->dev->irq;
-                dev_id = sh_pci_devs[minor];
                 if(i==0 || i==-1 || i==255) return -EINVAL;
-            } else dev_id = sdev_id;
-                        
-            vsync=1;
-
-            if(minor) {
-                request_irq(i, vsync_interrupt, SA_SHIRQ, "svgalib_helper", dev_id);
-            } else {
-                i=0;
-                while(irqs[i]!=-1)
-                    request_irq(irqs[i++], vsync_interrupt, SA_SHIRQ, "svgalib_helper", dev_id);
-            }
-
-            if(minor) {
+				sh_pci_devs[minor]->vsync=1;
                 sh_pci_devs[minor]->enable_vsync(sh_pci_devs[minor]);
+	            interruptible_sleep_on(&sh_pci_devs[minor]->vsync_wait);
+                if(sh_pci_devs[minor]->vsync) sh_pci_devs[minor]->ack_vsync(sh_pci_devs[minor]);
+            	if(sh_pci_devs[minor]->vsync) return -ERESTARTSYS;
             } else {
-                vga_enable_vsync(sh_pci_devs[minor]);
-            }
-
-            interruptible_sleep_on(&vsync_wait);
-            
-            if(minor) {
-                if(vsync) sh_pci_devs[minor]->ack_vsync(dev_id);
-                free_irq(i, dev_id);
-            } else {
+				int i;
+                vsync=1;
                 i=0;
-                if(vsync) vga_ack_vsync(dev_id);
                 while(irqs[i]!=-1)
-                    free_irq(irqs[i++], dev_id);
+                    request_irq(irqs[i++], vsync_interrupt, SA_SHIRQ, "svgalib_helper", sdev_id);
+                vga_enable_vsync((void *)sdev_id);
+				interruptible_sleep_on(&vsync_wait);
+                i=0;
+                if(vsync) vga_ack_vsync((void *)sdev_id);
+                while(irqs[i]!=-1)
+                    free_irq(irqs[i++], sdev_id);
+            	if(vsync) return -ERESTARTSYS;
             }
             
-            if(vsync) return -ERESTARTSYS;
             break;
+#ifndef NO_TASK
+		case _IOC_NR(SVGAHELPER_SETDISPLAYSTART):
+			if(minor) {
+				if(sh_pci_devs[minor]->startad==-1)
+					schedule_task(&sh_pci_devs[minor]->tq_startad);
+				sh_pci_devs[minor]->startad=arg;
+			}
+			break;
+#endif
 
 #ifdef SVGA_HELPER_VIRTUAL
         case _IOC_NR(SVGAHELPER_VIRT_TO_PHYS):
@@ -354,9 +371,16 @@ static int svgalib_helper_ioctl( struct inode *inode, struct file *filp,
 
 static int svgalib_helper_open( struct inode *inode, struct file * filp) {
 
-   int minor = my_minor(inode->i_rdev);
+	int minor = my_minor(inode->i_rdev);
    
-   if(minor>=num_devices) return -ENODEV;
+	if(minor>=num_devices) return -ENODEV;
+
+	if(minor) {
+		int i=sh_pci_devs[minor]->dev->irq;
+		sh_pci_devs[minor]->opencount++;
+		if(sh_pci_devs[minor]->opencount==1 && i!=0 && i!=-1 && i!=255)
+			request_irq(i, vsync_interrupt, SA_SHIRQ, "svgalib_helper", sh_pci_devs[minor]);
+	}
 
 #ifndef KERNEL_2_6
 	MOD_INC_USE_COUNT;
@@ -364,17 +388,28 @@ static int svgalib_helper_open( struct inode *inode, struct file * filp) {
 	try_module_get(THIS_MODULE);
 #endif
    
-   return 0;
+	return 0;
 }
 
 static int svgalib_helper_release( struct inode *inode, struct file *filp) {
+
+	int minor = my_minor(inode->i_rdev);
+
+	if(minor) {
+		int i=sh_pci_devs[minor]->dev->irq;
+		sh_pci_devs[minor]->opencount--;
+		if(sh_pci_devs[minor]->opencount==0 && i!=0 && i!=-1 && i!=255) {
+			sh_pci_devs[minor]->disable_vsync(sh_pci_devs[minor]);
+			free_irq(i, sh_pci_devs[minor]);
+		}
+	}
 #ifndef KERNEL_2_6
 	MOD_DEC_USE_COUNT;
 #else
 	module_put(THIS_MODULE);
 #endif
 	
-   return 0;
+	return 0;
 }
 
 int remap_cache(struct vm_area_struct *vma, unsigned long off) {
@@ -581,6 +616,15 @@ int init_module(void)
                 }
             }
             vga_init_vsync(sh_pci_devs[num_devices]);
+    		init_waitqueue_head(&sh_pci_devs[num_devices]->vsync_wait);
+#ifndef NO_TASK
+    		init_waitqueue_head(&sh_pci_devs[num_devices]->startad_wait);
+			sh_pci_devs[num_devices]->tq_startad.routine=task_startad;
+			sh_pci_devs[num_devices]->tq_startad.data=sh_pci_devs[num_devices];
+			sh_pci_devs[num_devices]->tq_startad.sync=0;
+			sh_pci_devs[num_devices]->startad=-1;
+#endif
+			sh_pci_devs[num_devices]->opencount=0;
             num_devices++;
         }
     }
@@ -591,13 +635,15 @@ int init_module(void)
         k=sh_pci_devs[i]->dev->irq;
         if(k>0 && k<255) {
             for(l=0;l<j;l++) if(k==irqs[l])k=-1;
-            if(k>0) irqs[j]=k;
-            j++;
+            if(k>0) {
+				irqs[j]=k;
+            	j++;
+			}
         }
     }
     irqs[j]=-1;
 
-    init_waitqueue_head(&vsync_wait);
+	init_waitqueue_head(&vsync_wait);
 
 #ifndef KERNEL_2_6
 	EXPORT_NO_SYMBOLS;
