@@ -193,7 +193,7 @@ static void apm_setregs(const unsigned char regs[], int mode)
 
 static int apm_modeavailable(int mode)
 {
-    struct info *info;
+    struct vgainfo *info;
     ModeTiming *modetiming;
     ModeInfo *modeinfo;
 
