@@ -387,7 +387,7 @@ static void cirrus_setregs(const unsigned char regs[], int mode)
 
 static int cirrus_modeavailable(int mode)
 {
-    struct info *info;
+    struct vgainfo *info;
     ModeTiming *modetiming;
     ModeInfo *modeinfo;
 
