@@ -561,7 +561,7 @@ static void et4000_setregs(const unsigned char regs[], int mode)
 static int et4000_modeavailable(int mode)
 {
     const unsigned char *regs;
-    struct info *info;
+    struct vgainfo *info;
 
     regs = LOOKUPMODE(et4000_modes, mode);
     if (regs == NULL || mode == GPLANE16)
