@@ -442,7 +442,7 @@ static void NeoCalcVCLK(long freq, unsigned char *moderegs)
 
 static int neo_modeavailable(int mode)
 {
-    struct info *info;
+    struct vgainfo *info;
     ModeTiming *modetiming;
     ModeInfo *modeinfo;
 
