@@ -275,7 +275,7 @@ static void oak_setregs(const unsigned char regs[], int mode)
 static int oak_modeavailable(int mode)
 {
     const unsigned char *regs;
-    struct info *info;
+    struct vgainfo *info;
 
     regs = LOOKUPMODE(oak_modes, mode);
     if (regs == NULL || mode == GPLANE16) {
