@@ -1024,7 +1024,7 @@ static void r128_setregs(const unsigned char regs[], int mode)
 
 static int r128_modeavailable(int mode)
 {
-    struct info *info;
+    struct vgainfo *info;
     ModeTiming *modetiming;
     ModeInfo *modeinfo;
 
