@@ -613,7 +613,7 @@ static void rage_setregs(const unsigned char regs[], int mode)
 
 static int rage_modeavailable(int mode)
 {
-    struct info *info;
+    struct vgainfo *info;
     ModeTiming *modetiming;
     ModeInfo *modeinfo;
 
