@@ -498,7 +498,7 @@ static void tvga8900_setregs(const unsigned char regs[], int mode)
 static int tvga8900_modeavailable(int mode)
 {
     const unsigned char *regs;
-    struct info *info;
+    struct vgainfo *info;
 
     regs = LOOKUPMODE(tvga_modes, mode);
     if (regs == NULL || mode == GPLANE16)
