@@ -139,7 +139,7 @@ static void vesa_setregs(const uint8_t regs[], int mode)
 
 static int vesa_modeavailable(int mode)
 {
-    struct info *info;
+    struct vgainfo *info;
     ModeTiming *modetiming;
     ModeInfo *modeinfo;
 
