@@ -28,6 +28,11 @@ extern struct termios __svgalib_graph_termio;	/* graphics mode termio parameters
 int __svgalib_vc=-1;
 extern int __svgalib_startup_vc;
 
+void vga_waitvtactive() {
+
+	if(__svgalib_novccontrol)return;
+	return __svgalib_waitvtactive();
+}
 
 void __svgalib_set_graphtermio(void)
 {
