@@ -92,7 +92,7 @@ int __svgalib_pci_read_config_byte(int pos, int address)
     p.pcipos = pos;
     p.address = address;
     
-    ioctl( __svgalib_mem_fd, SVGALIB_HELPER_IOCGPCIINB, &p);
+    ioctl( __svgalib_mem_fd, SVGAHELPER_PCIINB, &p);
     
     return p.val;
 };
@@ -104,7 +104,7 @@ int __svgalib_pci_read_config_word(int pos, int address)
     p.pcipos = pos;
     p.address = address;
     
-    ioctl( __svgalib_mem_fd, SVGALIB_HELPER_IOCGPCIINW, &p);
+    ioctl( __svgalib_mem_fd, SVGAHELPER_PCIINW, &p);
     
     return p.val;
 };
@@ -116,7 +116,7 @@ int __svgalib_pci_read_config_dword(int pos, int address)
     p.pcipos = pos;
     p.address = address;
     
-    if(ioctl( __svgalib_mem_fd, SVGALIB_HELPER_IOCGPCIINL, &p)) return -1;
+    if(ioctl( __svgalib_mem_fd, SVGAHELPER_PCIINL, &p)) return -1;
     
     return p.val;
 };
@@ -128,7 +128,7 @@ int __svgalib_pci_read_aperture_len(int pos, int address)
     p.pcipos = pos;
     p.address = address;
     
-    if(ioctl( __svgalib_mem_fd, SVGALIB_HELPER_IOCGPCIAPLEN, &p)) return -1;
+    if(ioctl( __svgalib_mem_fd, SVGAHELPER_PCIAPLEN, &p)) return -1;
     
     return p.val;
 };
@@ -141,7 +141,7 @@ void __svgalib_pci_write_config_byte(int pos, int address, unsigned char data)
     p.address = address;
     p.val = data;
     
-    ioctl( __svgalib_mem_fd, SVGALIB_HELPER_IOCSPCIOUTB, &p);
+    ioctl( __svgalib_mem_fd, SVGAHELPER_PCIOUTB, &p);
 };
 
 void __svgalib_pci_write_config_word(int pos, int address, unsigned short data)
@@ -152,7 +152,7 @@ void __svgalib_pci_write_config_word(int pos, int address, unsigned short data)
     p.address = address;
     p.val = data;
     
-    ioctl( __svgalib_mem_fd, SVGALIB_HELPER_IOCSPCIOUTW, &p);
+    ioctl( __svgalib_mem_fd, SVGAHELPER_PCIOUTW, &p);
 };
 
 void __svgalib_pci_write_config_dword(int pos, int address, unsigned int data)
@@ -163,7 +163,7 @@ void __svgalib_pci_write_config_dword(int pos, int address, unsigned int data)
     p.address = address;
     p.val = data;
     
-    ioctl( __svgalib_mem_fd, SVGALIB_HELPER_IOCSPCIOUTL, &p);
+    ioctl( __svgalib_mem_fd, SVGAHELPER_PCIOUTL, &p);
 };
 
 int memorytest(uint32_t *m, int max_mem) {
